@@ -22,7 +22,7 @@ copyright = '2020-2021, Sean Whitton'
 author = 'Sean Whitton'
 
 # The full version, including alpha/beta/rc tags
-release = '0.13.0'
+release = '0.14.0'
 
 
 # -- General configuration ---------------------------------------------------
@@ -55,3 +55,11 @@ html_theme = 'sphinx_rtd_theme'
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
 html_static_path = ['_static']
+
+
+# -- Options for Texinfo output ----------------------------------------------
+
+texinfo_documents = [("index", "consfigurator", "Consfigurator user's manual",
+                      "Sean Whitton", "Consfigurator",
+                      "Lisp declarative configuration management system",
+                      "System administration", False)]
