@@ -52,16 +52,8 @@ should be the mount point, without the chroot's root prefixed.")
         (apply #'mrun "mount" mount-args)
         (push dest (chroot-mounts connection))))))
 
-(defmethod connection-teardown :before ((connection chroot-connection))
-  (dolist (mount (chroot-mounts connection))
-    ;; There shouldn't be any processes left running in the chroot after we've
-    ;; finished deploying it, but it's quite easy to end up with things like
-    ;; gpg-agent holding on to /dev/null, for example, so for simplicity, do a
-    ;; lazy unmount.
-    (mrun "umount" "-l" mount)))
-
-(defmethod initialize-instance :after ((connection chroot-connection) &key)
-  (when (string= "Linux" (stripln (run "uname")))
+(defgeneric linux-chroot-mounts (connection)
+  (:method ((connection chroot-connection))
     (with-slots (into) connection
       ;; Ensure the chroot itself is a mountpoint so that findmnt(8) works
       ;; correctly within the chroot.
@@ -94,6 +86,10 @@ should be the mount point, without the chroot's root prefixed.")
     ((type (eql :remote-gid)) connattr (connection chroot-connection))
   connattr)
 
+(defmethod propagate-connattr
+    ((type (eql :no-services)) connattr (connection chroot-connection))
+  connattr)
+
 
 ;;;; :CHROOT.FORK
 
@@ -104,31 +100,35 @@ should be the mount point, without the chroot's root prefixed.")
   (unless (and (lisp-connection-p) (zerop (nix:geteuid)))
     (error "~&Forking into a chroot requires a Lisp image running as root"))
   (informat 1 "~&Forking into chroot at ~A" into)
-  (let* ((into (ensure-pathname into :want-absolute t :ensure-directory t))
+  (let* ((into (ensure-pathname into
+				:defaults (uiop:getcwd)
+				:ensure-absolute t :ensure-directory t))
          (connection (make-instance 'shell-chroot-connection :into into)))
     ;; Populate the CONSFIGURATOR::ID and :REMOTE-HOME connattrs correctly to
     ;; ensure they don't get bogus values when this connection object is used
     ;; in UPLOAD-ALL-PREREQUISITE-DATA.
     (connection-connattr connection :remote-home)
     ;; Obtain & cache XDG_CACHE_HOME inside the chroot, and compute DATADIR.
-    (let ((xdg-cache-home (connection-connattr connection :XDG-CACHE-HOME)))
+    (let ((xdg-cache-home (connection-connattr connection :XDG_CACHE_HOME)))
       (setf connection (change-class connection 'chroot.fork-connection)
             (slot-value connection 'datadir)
             (merge-pathnames
              "consfigurator/data/" (chroot-pathname xdg-cache-home into))))
-    (unwind-protect (continue-connection connection remaining)
-      (connection-teardown connection))))
+    (continue-connection connection remaining)))
 
 (defmethod post-fork ((connection chroot.fork-connection))
   (with-slots (into) connection
-    (unless (zerop
-             (foreign-funcall "chroot" :string (unix-namestring into) :int))
-      (error "chroot(2) failed!")))
-  (let ((home (connection-connattr connection :remote-home)))
-    (setf (getenv "HOME") (unix-namestring home))
-    ;; chdir, else our current working directory is a pointer to something
-    ;; outside the chroot
-    (uiop:chdir home)))
+    #+linux
+    (progn (unshare +CLONE_NEWNS+)
+           (mrun "mount" "--make-rslave"
+                 (stripln (run "findmnt" "-nro" "TARGET" "-T" into)))
+           (linux-chroot-mounts connection))
+    (chroot (unix-namestring into))
+    (let ((home (connection-connattr connection :remote-home)))
+      (setf (getenv "HOME") (unix-namestring home))
+      ;; chdir, else our current working directory is a pointer to something
+      ;; outside the chroot
+      (uiop:chdir home))))
 
 
 ;;;; :CHROOT.SHELL
@@ -136,7 +136,9 @@ should be the mount point, without the chroot's root prefixed.")
 (defmethod establish-connection ((type (eql :chroot.shell)) remaining &key into)
   (declare (ignore remaining))
   (informat 1 "~&Shelling into chroot at ~A" into)
-  (make-instance 'shell-chroot-connection :into into))
+  (aprog1 (make-instance 'shell-chroot-connection :into into)
+    (when (string= "Linux" (stripln (run "uname")))
+      (linux-chroot-mounts it))))
 
 (defclass shell-chroot-connection (chroot-connection shell-wrap-connection) ())
 
@@ -144,3 +146,11 @@ should be the mount point, without the chroot's root prefixed.")
   (format nil "chroot ~A sh -c ~A"
           (escape-sh-token (unix-namestring (slot-value connection 'into)))
           (escape-sh-token cmd)))
+
+(defmethod connection-teardown :before ((connection shell-chroot-connection))
+  (dolist (mount (chroot-mounts connection))
+    ;; There shouldn't be any processes left running in the chroot after we've
+    ;; finished deploying it, but it's quite easy to end up with things like
+    ;; gpg-agent holding on to /dev/null, for example, so for simplicity, do a
+    ;; lazy unmount.
+    (mrun "umount" "-l" mount)))
