@@ -24,7 +24,8 @@
   (unless (and (lisp-connection-p) (zerop (nix:geteuid)))
     (error "~&SETUIDing requires a Lisp image running as root"))
   (informat 1 "~&SETUIDing to ~A" to)
-  (let* ((ent (osicat:user-info to))
+  (let* ((ent (or (osicat:user-info to)
+                  (failed-change "~&Could not look up user info for ~A." to)))
 	 (xdg-cache-home
            (ensure-directory-pathname
             (stripln
@@ -33,17 +34,24 @@
              ;; argument to su(1) on, e.g., FreeBSD.  So should be fairly
              ;; portable.
              (mrun "su" (cdr (assoc :name ent))
-		   "-c" "echo ${XDG_CACHE_HOME:-$HOME/.cache}")))))
+		   "-c" "echo ${XDG_CACHE_HOME:-$HOME/.cache}"))))
+         (cache (merge-pathnames "consfigurator/" xdg-cache-home))
+         (datadir (merge-pathnames "data/" cache)))
+    (dolist (dir (list xdg-cache-home cache datadir))
+      (unless (directory-exists-p dir)
+        (nix:chown (ensure-directories-exist dir)
+                   (cdr (assoc :user-id ent)) (cdr (assoc :group-id ent)))))
     (continue-connection
      (make-instance
       'setuid-connection
-      :datadir (merge-pathnames "consfigurator/data/" xdg-cache-home)
+      :datadir datadir
       :connattrs `(:remote-uid ,(cdr (assoc :user-id ent))
                    :remote-gid ,(cdr (assoc :group-id ent))
                    :remote-user ,(cdr (assoc :name ent))
                    :remote-home ,(ensure-directory-pathname
                                   (cdr (assoc :home ent)))
-                   :XDG-CACHE-HOME ,xdg-cache-home))
+                   :consfigurator-cache ,cache
+                   :XDG_CACHE_HOME ,xdg-cache-home))
      remaining)))
 
 (defmethod post-fork ((connection setuid-connection))
@@ -54,6 +62,10 @@
                        (format nil "~A:~A" uid gid)
                        (unix-namestring (slot-value connection 'datadir))))
     (posix-login-environment
-     user (connection-connattr connection :remote-home))
+     uid user (connection-connattr connection :remote-home))
     ;; We are privileged, so this sets the real, effective and saved IDs.
     (nix:setgid gid) (nix:initgroups user gid) (nix:setuid uid)))
+
+(defmethod propagate-connattr
+    ((type (eql :no-services)) connattr (connection setuid-connection))
+  connattr)
