@@ -23,13 +23,14 @@
 (defgeneric connection-shell-wrap (connection cmd))
 
 (defmethod connection-run ((c shell-wrap-connection) cmd input)
-  (mrun :may-fail :input input (connection-shell-wrap c cmd)))
+  (apply #'mrun :may-fail :input input
+         (ensure-cons (connection-shell-wrap c cmd))))
 
 (defun %readfile (c path &optional delete)
   (multiple-value-bind (out exit)
       (let* ((path (escape-sh-token path))
              (base #?"test -r ${path} && cat ${path}")
-             (cmd (if delete (strcat base #?"&& rm ${path}") base)))
+             (cmd (if delete (strcat base #?" && rm ${path}") base)))
         (connection-run c cmd nil))
     (if (zerop exit)
         out
