@@ -403,7 +403,8 @@ no risk of clashes between fresly generated files and cached copies of files."
      (if version pn (ensure-directory-pathname pn)))))
 
 (defun remote-data-pathname (&rest args)
-  (apply #'data-pathname (get-remote-data-cache-dir) args))
+  (apply #'data-pathname
+         (merge-pathnames "data/" (get-connattr :consfigurator-cache)) args))
 
 
 ;;;; Remote caches
@@ -420,13 +421,12 @@ of CONNECTION, where each entry is of the form
     (mapcar (lambda (line)
               (mapcar #'filename->string (split-string line :separator "/")))
             (multiple-value-bind (out exit)
-                (mrun :may-fail "find" (get-remote-data-cache-dir)
+                (mrun :may-fail "find" (merge-pathnames
+                                        "data/"
+                                        (get-connattr :consfigurator-cache))
                       "-type" "f" "-printf" "%P\\n")
               (and (zerop exit) (lines out))))))
 
-(defun get-remote-data-cache-dir ()
-  (remote-consfigurator-cache-pathname "data/"))
-
 
 ;;;; Local caches
 
@@ -469,7 +469,17 @@ properties, or data sources which return objects referencing existing files."
 			      :version (caddr triple))))
 
 (defun get-local-data-cache-dir ()
-  (merge-pathnames "consfigurator/data/" (uiop:xdg-cache-home)))
+  (merge-pathnames
+   "data/"
+   ;; A combinator like WITH-HOMEDIR might have temporarily set the HOME
+   ;; and/or XDG_CACHE_HOME environment variables, so use a cached value if we
+   ;; can find one.
+   (or (loop for conn = *connection* then (connection-parent conn)
+             while conn
+             when (subtypep (type-of conn) 'lisp-connection)
+               return (connection-connattr conn :consfigurator-cache))
+       (connection-connattr
+        (establish-connection :local nil) :consfigurator-cache))))
 
 
 ;;;; Passphrases
