@@ -18,6 +18,8 @@
 (in-package :consfigurator.property.cmd)
 (named-readtables:in-readtable :consfigurator)
 
+;; The name of this property comes from the idea that we might want to add a
+;; property in this package to run a user-supplied shell script.
 (defprop single :posix (&rest args)
   "A property which can be applied by running a single shell command.  ARGS is
 either a single string specifying a shell-escaped command, or number of
@@ -27,4 +29,9 @@ strings which will be shell-escaped and then concatenated.
 
 Keyword argument :ENV is a plist of environment variables to be set when
 running the command, using env(1)."
-  (:apply (apply #'run args)))
+  (:desc (loop for arg in args
+               if (stringp arg)
+                 collect (escape-sh-token arg) into accum
+               else collect (prin1-to-string arg) into accum
+               finally (return (format nil "~{~A~^ ~}" accum))))
+  (:apply (apply #'mrun args)))
