@@ -18,7 +18,7 @@
 (in-package :consfigurator.property.fstab)
 (named-readtables:in-readtable :consfigurator)
 
-;;; Use of findmnt(1) makes much of this Linux-specific.
+;;; Use of findmnt(8) makes much of this Linux-specific.
 
 ;;;; Methods on volumes to get strings for fstab
 
@@ -58,7 +58,7 @@ Other properties might fill it in."
   "vfat")
 
 (defmethod fs-mntops ((volume filesystem))
-  (or (mount-options volume) '("none")))
+  (or (mount-options volume) '("defaults")))
 
 (defmethod fs-freq ((volume filesystem))
   0)
@@ -85,10 +85,8 @@ member of ENTRIES is \"none\", or \"PLACEHOLDER\", use the existing field value.
 
 This makes it easy to update mount options without having to specify the
 partition or filesystem UUID in your consfig."
-  (:desc
-   (let ((mount-points (mapcar (compose #'cadr #'words) entries)))
-     (format nil "fstab entr~@P for ~{~A~^, ~}"
-             (length mount-points) mount-points)))
+  (:desc (alet (mapcar (compose #'cadr #'words) entries)
+           (format nil "fstab entr~@P for ~{~A~^, ~}" (length it) it)))
   (:apply (file:update-unix-table #P"/etc/fstab" 0 1 entries)))
 
 (defprop entries-for-volumes :posix (&optional volumes)
