@@ -28,6 +28,12 @@
     :documentation
     "Keyword whose name is Debian's name for this architecture, e.g. :AMD64")))
 
+(defprop linux :posix (architecture)
+  (:desc "Host kernel is Linux")
+  (:hostattrs (push-hostattrs :os (make-instance 'linux :arch architecture))))
+
+(define-print-object-for-structlike linux)
+
 (defclass debianlike (linux) ())
 
 (defclass debian (debianlike)
@@ -39,6 +45,9 @@
 
 (defclass debian-stable (debian) ())
 
+(defun debian-stable (suite)
+  (make-instance 'debian-stable :suite suite))
+
 (defprop debian-stable :posix (suite architecture)
   (:desc
    (declare (ignore architecture))
@@ -51,6 +60,9 @@
 (defclass debian-testing (debian)
   ((suite :initform "testing")))
 
+(defun debian-testing ()
+  (make-instance 'debian-testing))
+
 (defprop debian-testing :posix (architecture)
   (:desc
    (declare (ignore architecture))
@@ -63,6 +75,9 @@
 (defclass debian-unstable (debian)
   ((suite :initform "unstable")))
 
+(defun debian-unstable ()
+  (make-instance 'debian-unstable))
+
 (defprop debian-unstable :posix (architecture)
   (:desc
    (declare (ignore architecture))
@@ -72,6 +87,12 @@
                    (make-instance 'debian-unstable
                                   :arch architecture))))
 
+(defclass debian-experimental (debian)
+  ((suite :initform "experimental")))
+
+(defun debian-experimental ()
+  (make-instance 'debian-experimental))
+
 (defmethod debian-architecture ((os linux))
   "Return a string representing the architecture of OS as used by Debian."
   (string-downcase (symbol-name (linux-architecture os))))
@@ -138,8 +159,10 @@ Used in property :HOSTATTRS subroutines."
 
 (defun supports-arch-p (os arch)
   "Can binaries of type ARCH run on OS?"
-  (cl:typecase os
-    (debian (or (eq (linux-architecture os) arch)
-                (member arch (assoc (linux-architecture os)
-                                    '((:amd64 :i386)
-                                      (:i386  :amd64))))))))
+  (let ((same (eq (linux-architecture os) arch)))
+    (cl:typecase os
+      (debian (or same
+                  (member arch (assoc (linux-architecture os)
+                                      '((:amd64 :i386)
+                                        (:i386  :amd64))))))
+      (linux same))))
