@@ -30,7 +30,10 @@
   "Set key--value pairs in /etc/ssh/sshd_config."
   (:desc (format nil "sshd configured ~{~A ~A~^, ~}" pairs))
   (:apply
-   (apply #'file:contains-conf-space "/etc/ssh/sshd_config" pairs)))
+   (if (eql :no-change
+            (apply #'file:contains-conf-space "/etc/ssh/sshd_config" pairs))
+       :no-change
+       (service:reloaded "sshd"))))
 
 (defprop no-passwords :posix ()
   "Configure SSH to disallow password logins.
@@ -42,7 +45,7 @@ refuses to proceed if root has no authorized_keys."
    (unless (and (remote-exists-p ".ssh/authorized_keys")
                 (plusp (length (readfile ".ssh/authorized_keys"))))
      (failed-change "root has no authorized_keys"))
-   (configured "PermitRootLogin" "without-password"
+   (configured "PermitRootLogin" "prohibit-password"
                "PasswordAuthentication" "no")))
 
 
@@ -64,10 +67,14 @@ The private key is obtained as an item of prerequisite data."
   (file:host-secret-uploaded (merge-pathnames (strcat "ssh_host_" type "_key")
                                               #P"/etc/ssh/")))
 
-(defun get-host-public-keys (host &key short-hostname)
+(defun get-host-public-keys (host &key short-hostname (aliases t)
+                                    (ips t) additional-names)
   (let* ((host (preprocess-host host))
-         (hostname (get-hostname host)))
-    (cons (format nil "~A~:[~;,~A~]"
-                  hostname (and short-hostname (find #\. hostname))
-                  (car (split-string hostname :separator ".")))
+         (hostname (get-hostname host))
+         (short (and short-hostname (list (get-short-hostname host))))
+         (aliases (and aliases (get-hostattrs :aliases host)))
+         (ips (and ips (append (get-hostattrs :ipv6 host)
+                               (get-hostattrs :ipv4 host)))))
+    (cons (format nil "~{~A~^,~}"
+                  (cons hostname (append aliases short ips additional-names)))
           (mapcar #'cdr (get-hostattrs 'host-public-key host)))))
