@@ -40,10 +40,12 @@
   (declare (ignore args))
   (values))
 
-(defun lines (text)
+(defun lines (text &optional trimfun (trimchars '(#\Space #\Tab)))
   (with-input-from-string (stream text)
     (let (bolp buffer)
-      (flet ((reset ()
+      (flet ((trim (line)
+               (if trimfun (funcall trimfun trimchars line) line))
+             (reset ()
                (setq bolp t
                      buffer (make-array 0 :fill-pointer 0
                                           :element-type 'character))))
@@ -53,7 +55,7 @@
               for char = (read-char stream nil nil)
               if char
                 if (member char '(#\Return #\Newline) :test #'char=)
-                  collect buffer
+                  collect (trim buffer)
                   and do (reset)
                          (when (char= char #\Return)
                            (when-let ((next (peek-char nil stream nil nil)))
@@ -63,7 +65,7 @@
                         (vector-push-extend char buffer)
                 end
               else
-                unless bolp collect buffer end
+                unless bolp collect (trim buffer) end
                 and do (loop-finish))))))
 
 (defun unlines (lines)
@@ -369,9 +371,10 @@ expansion as a starting point for your own DEFPACKAGE form for your consfig."
                         (car args))
    :int))
 
-(define-constant +alphanum+
-  "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
-  :test #'string=)
+(eval-when (:compile-toplevel :load-toplevel :execute)
+  (define-constant +alphanum+
+    "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
+    :test #'string=))
 
 (defun random-alphanumeric (length)
   "Return a random alphanumeric string of length LENGTH."
@@ -468,20 +471,44 @@ previous output."
 
 ;;;; Version numbers
 
-(defun number->string (x)
-  (etypecase x (string x) (number (format nil "~D" x))))
+(defun compare-versions (x y &optional less-than-or-equal)
+  (flet
+      ((components (v)
+         (etypecase v
+           (number (list v))
+           (string
+            (loop with buf
+                    = (make-array 0 :fill-pointer 0 :element-type 'character)
+                  for c across v
+                  if (digit-char-p c)
+                    do (vector-push-extend c buf)
+                  else if (and (char= c #\.) (plusp (fill-pointer buf)))
+                         collect (parse-integer buf) into accum
+                         and do (setf (fill-pointer buf) 0)
+                  else do (loop-finish)
+                  finally (return (if (plusp (fill-pointer buf))
+                                      (nconc accum (list (parse-integer buf)))
+                                      accum)))))))
+    (setq x (components x) y (components y))
+    (if less-than-or-equal
+        (loop while (or x y) for a = (or (pop x) 0) and b = (or (pop y) 0)
+              never (> a b)
+              if (< a b) return t)
+        (loop while (or x y) for a = (or (pop x) 0) and b = (or (pop y) 0)
+              thereis (> b a)
+              if (< b a) return nil))))
 
 (defun version< (x y)
-  (uiop:version< (number->string x) (number->string y)))
-
-(defun version> (x y)
-  (version< y x))
+  (compare-versions x y))
 
 (defun version<= (x y)
-  (uiop:version<= (number->string x) (number->string y)))
+  (compare-versions x y t))
+
+(defun version> (x y)
+  (compare-versions y x))
 
 (defun version>= (x y)
-  (version<= y x))
+  (compare-versions y x t))
 
 
 ;;;; Encoding of strings to filenames
